[Date Prev][Date Next] [Thread Prev][Thread Next] [Date Index] [Thread Index]

Bug#733489: [PATCH] apt/package.py: Replaced pre_depend with rawtype in BaseDependency.__repr__ as rawtype gives more information including the information from pre_depend.



---
 apt/package.py   | 4 ++--
 debian/changelog | 6 ++++++
 2 files changed, 8 insertions(+), 2 deletions(-)

diff --git a/debian/changelog b/debian/changelog
index 2dc57e6..e14d29b 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -1,5 +1,6 @@
 python-apt (1.0.0~beta3) unstable; urgency=medium
 
+  [ Julian Andres Klode ]
   * tests/test_paths.py: Catch and assert the DeprecationWarning
   * setup.py: If no version is in the environment, return None
   * doc/source/library/apt_pkg.rst: Fix an example from old API to new API
@@ -9,6 +10,11 @@ python-apt (1.0.0~beta3) unstable; urgency=medium
   * apt.Cache: Issue a RuntimeWarning in connect()
   * doc: whatsnew: Document what's new in beta3
 
+  [ Michael Schaller ]
+  * apt/package.py: Replaced pre_depend with rawtype in BaseDependency.__repr__
+    as rawtype gives more information including the information from
+    pre_depend.
+
  -- Julian Andres Klode <jak@debian.org>  Wed, 17 Jun 2015 18:28:44 +0200
 
 python-apt (1.0.0~beta2) unstable; urgency=low

Reply to:
diff --git a/apt/package.py b/apt/package.py
index 641b1a4..391ee4f 100644
--- a/apt/package.py
+++ b/apt/package.py
@@ -130,8 +130,8 @@ class BaseDependency(object):
         return self._dep.dep_type_untranslated == 'PreDepends'
 
     def __repr__(self):
-        return ('<BaseDependency: name:%r relation:%r version:%r preDepend:%r>'
-                % (self.name, self.relation, self.version, self.pre_depend))
+        return ('<BaseDependency: name:%r relation:%r version:%r rawtype:%r>'
+                % (self.name, self.relation, self.version, self.rawtype))
 
 
 class Dependency(list):